import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * @usedBy PoPageJobScheduler
 *
 * @description
 *
 * Esta diretiva permite personalizar o conteúdo da uma ou várias etapa(s) de parametrização do componente de PoPageJobScheduler.
 *
 * Para repassar as alterações realizadas no componente customizado ao model do PoPageJobScheduler, deve
 * ser atualizado os valores através da propriedade p-execution-parameter. Dessa forma as alterações serão adicionadas ao
 * atributo executionParameter do objeto de envio a Api.
 * É possível também controlar a permissão de avançar, fazendo uso da propriedade p-disable-advance.
 *
 * ```
 * ...
 * <po-page-job-scheduler [p-service-api]="serviceApi">
 *     <ng-template p-job-scheduler-parameters-template
 *      [p-execution-parameter]="executionParameter"
 *      [p-disable-advance]="disableAdvance"
 *      p-label-step="titleStep"
 *     >
 *       ...
 *     </ng-template>
 *     <ng-template p-job-scheduler-parameters-template
 *      [p-execution-parameter]="executionParameter"
 *      [p-disable-advance]="disableAdvance"
 *      p-label-step="titleStep"
 *     >
 *       ...
 *     </ng-template>
 * </po-page-job-scheduler>
 * ...
 * ```
 *
 */
export declare class PoJobSchedulerParametersTemplateDirective {
    templateRef: TemplateRef<any>;
    /**
     * @optional
     *
     * @description
     *
     * Objeto que deve conter as alterações feitas pelo componente de template que serão repassadas dentro do atributo
     * `executionParameter` para envio na api.
     *
     * > O componente deve manter essa propriedade atualizada. É chamada após o avançar da etapa de parametrização.
     */
    executionParameter: object;
    /**
     * @optional
     *
     * @default false
     *
     * @description
     *
     * Determina se deve desabilitar o botão de avançar para a próxima etapa
     *
     * > Pode ser utilizado para validar campos antes de avançar.
     */
    disabledAdvance: boolean;
    /**
     * @optional
     *
     * @description
     *
     * Determina o label do step
     */
    title: string;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<PoJobSchedulerParametersTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PoJobSchedulerParametersTemplateDirective, "[p-job-scheduler-parameters-template]", never, { "executionParameter": { "alias": "p-execution-parameter"; "required": false; }; "disabledAdvance": { "alias": "p-disable-advance"; "required": false; }; "title": { "alias": "p-label-step"; "required": false; }; }, {}, never, never, false, never>;
}
