import { AfterContentInit, OnInit, QueryList } from '@angular/core';
import { NgForm } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';
import { PoDialogService, PoLanguageService, PoNotificationService, PoPageAction, PoStepperItem, PoThemeService } from '@po-ui/ng-components';
import { PoJobSchedulerInternal } from './interfaces/po-job-scheduler-internal.interface';
import { PoPageJobSchedulerBaseComponent } from './po-page-job-scheduler-base.component';
import { PoPageJobSchedulerLookupService } from './po-page-job-scheduler-lookup.service';
import { PoJobSchedulerParametersTemplateDirective } from './po-page-job-scheduler-parameters';
import { PoJobSchedulerSummaryTemplateDirective } from './po-page-job-scheduler-summary';
import { PoPageJobSchedulerService } from './po-page-job-scheduler.service';
import * as i0 from "@angular/core";
/**
 * @docsExtends PoPageJobSchedulerBaseComponent
 *
 * @example
 *
 * <example name="po-page-job-scheduler-background-process" title="PO Page Job Scheduler - Background Process">
 *  <file name="sample-po-page-job-scheduler-background-process/sample-po-page-job-scheduler-background-process.component.html"> </file>
 *  <file name="sample-po-page-job-scheduler-background-process/sample-po-page-job-scheduler-background-process.component.ts"> </file>
 * </example>
 *
 * <example name="po-page-job-scheduler-directives" title="PO Page Job Scheduler - Directives">
 *  <file name="sample-po-page-job-scheduler-directives/sample-po-page-job-scheduler-directives.component.html"> </file>
 *  <file name="sample-po-page-job-scheduler-directives/sample-po-page-job-scheduler-directives.component.ts"> </file>
 * </example>
 *
 */
export declare class PoPageJobSchedulerComponent extends PoPageJobSchedulerBaseComponent implements OnInit, AfterContentInit {
    poPageDynamicLookupService: PoPageJobSchedulerLookupService;
    private activatedRoute;
    private poDialogService;
    private poNotification;
    protected poThemeService: PoThemeService;
    protected poPageJobSchedulerService: PoPageJobSchedulerService;
    schedulerExecution: {
        form: NgForm;
    };
    schedulerParameters: {
        form: NgForm;
    };
    parametersTemplate: QueryList<PoJobSchedulerParametersTemplateDirective>;
    jobSchedulerSummaryTemplate: PoJobSchedulerSummaryTemplateDirective;
    isEdit: boolean;
    literals: {
        at: string;
        back: string;
        next: string;
        periodicity: string;
        execution: string;
        process: string;
        enterProcess: string;
        recurrent: string;
        single: string;
        daily: string;
        weekly: string;
        monthly: string;
        scheduling: string;
        parameterization: string;
        conclude: string;
        firstExecution: string;
        startTime: string;
        endTime: string;
        time: string;
        hour: string;
        minute: string;
        day: string;
        endDay: string;
        startDay: string;
        weekDays: string;
        sunday: string;
        monday: string;
        tuesday: string;
        wednesday: string;
        thursday: string;
        friday: string;
        saturday: string;
        parameters: string;
        yes: string;
        no: string;
        notReported: string;
        periodicityData: string;
        confirmation: string;
        confirmSaveMessage: string;
        confirmUpdateMessage: string;
        saveNotificationSuccessUpdate: string;
        saveNotificationSuccessSave: string;
        parametersNotFound: string;
        frequency: string;
        to: string;
        from: string;
    };
    publicValues: PoJobSchedulerInternal;
    saveOperation: Observable<any>;
    step: number;
    parametersEmpty: boolean;
    stepParametersInitialized: boolean;
    protected steps: Array<PoStepperItem>;
    private backPageAction;
    private concludePageAction;
    private nextPageAction;
    private concludePageActions;
    private nextPageActions;
    jobSchedulerActions: Array<PoPageAction>;
    protected stepExecution: number;
    protected stepParameters: number;
    protected stepSummary: number;
    protected _stepExecutionLast: boolean;
    constructor(poPageDynamicLookupService: PoPageJobSchedulerLookupService, activatedRoute: ActivatedRoute, poDialogService: PoDialogService, poNotification: PoNotificationService, poThemeService: PoThemeService, poPageJobSchedulerService: PoPageJobSchedulerService, languageService: PoLanguageService);
    get stepperOrientation(): 'horizontal' | 'vertical';
    ngOnInit(): void;
    ngAfterContentInit(): void;
    changePageActionsBySteps(currentStep: number, nextStep: number): void;
    nextStep(stepNumber: number): void;
    onChangeProcess(process: {
        processId: string;
        existAPI: boolean;
    }): void;
    private checkStepExecutionLast;
    private confirmJobScheduler;
    private emitSuccessMessage;
    private getParametersByProcess;
    private hidesSecretValues;
    private getSteps;
    private getTemplateCurrent;
    private templateHasDisable;
    private isDisabledAdvance;
    private isDisabledBack;
    private isSecretParameter;
    private nextStepOperation;
    private resetJobSchedulerForm;
    private save;
    private setModelRecurrent;
    private setPropertiesFromTemplate;
    private validateStepExecution;
    private validateStepSchedulerParameters;
    private validateStepTemplateParameters;
    static ɵfac: i0.ɵɵFactoryDeclaration<PoPageJobSchedulerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PoPageJobSchedulerComponent, "po-page-job-scheduler", never, {}, {}, ["jobSchedulerSummaryTemplate", "parametersTemplate"], never, false, never>;
}
